@@ -14,7 +14,7 @@ class PaymentGatewayRequest:
         _session = Session()
         _request = Request(
             method,
-            f'http://127.0.0.1:8050/api/v1/{uri}',
+            f'https://134.122.118.178/api/v1/{uri}',
             data=json.dumps(data),
             headers={
                 'Authorization': f'Bearer {self.key}',
@@ -24,7 +24,7 @@ class PaymentGatewayRequest:
 
         _prepared = _request.prepare()
         _response = _session.send(
-            _prepared, verify=True, allow_redirects=False)
+            _prepared,  allow_redirects=False)
 
         return _response
 
